@@ -1,17 +1,6 @@
 #!/bin/bash
 
-if [ "z" -ne "z${1}"]; then
-    RELEASE_VERSION=${1}
-else
-    RELEASE_VERSION=2013.2
-fi
-
-if [ "z" -ne "z${2}"]; then
-    BUILD_DIR=${2}/build_$(date +%Y%m%d%H%M)/unknown-horizons
-else
-    RELEASE_VERSION=2013.2
-fi
-
+RELEASE_VERSION=2013.3
 
 BUILD_DIR="../../build/build_$(date +%Y%m%d%H%M)/unknown-horizons"
 echo "Creating build folder: $BUILD_DIR"
@@ -35,7 +24,7 @@ cd ..
 echo "Running Setup..."
 cd development
 python2 compile_translation_win.py
-python2 generate_atlases.py 1024
+python2 ../horizons/engine/generate_atlases.py 1024
 cd ..
 
 echo "Cleaning up"
