@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -24,7 +24,7 @@
 #
 # == I18N DEV USE CASES: CHEATSHEET ==
 #
-# ** Refer to  development/copy_pofiles.sh  for help with building or updating
+# ** Refer to  development/create_pot.sh  for help with building or updating
 #    the translation files for Unknown Horizons.
 #
 ###############################################################################
@@ -33,13 +33,14 @@
 #
 ###############################################################################
 
+import os
 import sqlalchemy
 import sqlalchemy.orm
 import sqlalchemy.ext.declarative
 import sqlite3
-import tempfile
-import os
 import sys
+import tempfile
+from collections import defaultdict
 
 sys.path.append(".")
 sys.path.append("./horizons")
@@ -91,23 +92,20 @@ class SettlerLevel(Base):
 #
 
 class MSGID_collect:
-	msgids = {}
+	msgids = defaultdict(list)
 
 	def __init__(self):
 		pass
 
 	def add_to_collection(self, msgid, place):
-		if self.msgids.has_key(msgid):
-			self.msgids[msgid].append(place)
-		else:
-			self.msgids[msgid] = [place]
+		self.msgids[msgid].append(place)
 
 	def __str__(self):
 		s = []
 		for text, locations in self.msgids.items():
-			comment = '#. This is a database entry: %s.\n#: sql-database-files\n' % ','.join(locations)
+			comment = '#. This is a database entry: %s.\n' % ','.join(locations)
 			if "{" in text and "}" in text:
-				comment += '#, python-format\n'
+				comment += '#, python-brace-format\n'
 			s += [comment + build_msgid(text)]
 		return '\n'.join(s).strip()
 
