@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -69,6 +69,8 @@ class BUILDING_PURPOSE:
 	TOBACCONIST = 29
 	SALT_PONDS = 30
 	FIRE_STATION = 31
+	DOCTOR = 32
+	HERBARY = 33
 
 	purpose_to_building = {}
 	building_to_purpose = {}
@@ -104,6 +106,8 @@ class BUILDING_PURPOSE:
 		cls.purpose_to_building[cls.TOBACCONIST] = BUILDINGS.TOBACCONIST
 		cls.purpose_to_building[cls.SALT_PONDS] = BUILDINGS.SALT_PONDS
 		cls.purpose_to_building[cls.FIRE_STATION] = BUILDINGS.FIRE_STATION
+		cls.purpose_to_building[cls.DOCTOR] = BUILDINGS.DOCTOR
+		cls.purpose_to_building[cls.HERBARY] = BUILDINGS.HERBARY
 
 		for purpose, building_id in cls.purpose_to_building.iteritems():
 			cls.building_to_purpose[building_id] = purpose
