@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -97,6 +97,9 @@ class DefaultPersonality:
 		max_fire_station_capacity = 40 # maximum number of residences a fire station can service
 		normal_fire_station_capacity = 30 # the initial plan calls for this number of residences per fire station
 
+		max_doctor_capacity = 40 # maximum number of residences a doctor can service
+		normal_doctor_capacity = 30 # the initial plan calls for this number of residences per doctor
+
 		min_coverage_building_options = 10 # consider at least this many coverage building options
 		coverage_building_option_ratio = 0.4 # consider this * 100% of the possible options
 
@@ -376,6 +379,18 @@ class DefaultPersonality:
 		residences_required = 0
 		min_settler_level = TIER.SETTLERS
 
+	class MedicalHerbsProductsGoal:
+		enabled = True
+		default_priority = 230
+		residences_required = 13
+		min_settler_level = TIER.SETTLERS
+
+	class FeederMedicalProductsGoal:
+		enabled = True
+		default_priority = 230
+		residences_required = 0
+		min_settler_level = TIER.SETTLERS
+
 	class AbstractVillageBuilding:
 		fraction_of_assigned_residences_built = 0.75 # build a coverage building if at least this amount of the assigned residences have been built
 
@@ -454,19 +469,30 @@ class DefaultPersonality:
 		add_pasture_value = 2.5 # the value of adding a pasture
 		add_sugarcane_field_value = 3.5 # the value of adding a sugarcane field
 		add_tobacco_field_value = 3.5 # the value of adding a tobacco field
+		add_herbary_field_value = 3.5 # the value of adding a herbary
 		remove_unused_potato_field_penalty = 0 # the penalty for removing an unused potato field
 		remove_unused_pasture_penalty = 1 # the penalty for removing an unused pasture
 		remove_unused_sugarcane_field_penalty = 1.5 # the penalty for removing an unused sugarcane field
 		remove_unused_tobacco_field_penalty = 1.5 # the penalty for removing an unused tobacco field
+		remove_unused_herbary_field_penalty = 1.5 # the penalty for removing an unused herbary
 
 	class FireStationGoal:
 		enabled = True
 		default_priority = 690
 		residences_required = 5
-		min_settler_level = TIER.SAILORS
+		min_settler_level = TIER.PIONEERS
+
+	class DoctorGoal:
+		enabled = True
+		default_priority = 650
+		residences_required = 5
+		min_settler_level = TIER.SETTLERS
 
 	class AbstractFireStation:
 		fraction_of_assigned_residences_built = 0.4 # build a fire station if at least this amount of the assigned residences have been built
 
+	class AbstractDoctor:
+		fraction_of_assigned_residences_built = 0.4 # build a doctor if at least this amount of       the assigned residences have been built
+
 	class AbstractFisher:
 		max_options = 30 # maximum number of farm options to consider
