@@ -1,6 +1,6 @@
 # -.- coding: utf-8 -.-
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -60,15 +60,19 @@ class VERSION:
 		return u"<unknown>"
 
 	RELEASE_NAME    = "Unknown Horizons %s"
-	RELEASE_VERSION = u'2013.2'
+	RELEASE_VERSION = u'2013.3'
 	# change for release:
 	IS_DEV_VERSION = False
-	#RELEASE_VERSION = u'2013.2'
+	#RELEASE_VERSION = u'2013.3'
 
-	MIN_FIFE_REVISION = 4103
+	REQUIRED_FIFE_MAJOR_VERSION = 0
+	REQUIRED_FIFE_MINOR_VERSION = 3
+	REQUIRED_FIFE_PATCH_VERSION = 4
+
+	REQUIRED_FIFE_VERSION = (REQUIRED_FIFE_MAJOR_VERSION, REQUIRED_FIFE_MINOR_VERSION, REQUIRED_FIFE_PATCH_VERSION)
 
 	## +=1 this if you changed the savegame "api"
-	SAVEGAMEREVISION = 71
+	SAVEGAMEREVISION = 73
 
 	@staticmethod
 	def string():
@@ -178,7 +182,7 @@ class BUILDINGS:
 	class ACTION:
 		# data for calculating gfx for paths.
 		# think: animation contains key, if there is a path at offset value
-		# you need to sort this before iterating via sorted, since order is important here
+		# you need to sort this before iterating via sorted, since order is important here.
 		action_offset_dict = {
 		# Direct connections
 		  'a' : ( 0, -1),
@@ -255,6 +259,7 @@ class RES:
 	ALVEARIES        = 59
 	HONEYCOMBS       = 60
 	FIRE             = 99
+	BLACKDEATH			 = 98
 
 class GROUND:
 	DEFAULT_LAND = (3, "straight", 45)
@@ -345,8 +350,8 @@ class PRODUCTIONLINES:
 
 ## GAME-RELATED, BALANCING VALUES
 class GAME:
-	INGAME_TICK_INTERVAL = 30 # seconds. duration of a "month" (running costs and taxes are
-	# payed in this interval).
+	# seconds: duration of a "month" (running costs and taxes are paid in this interval)
+	INGAME_TICK_INTERVAL = 30
 
 	WORLD_WORLDID = 0 # worldid of World object
 	MAX_TICKS = None # exit after on tick MAX_TICKS (disabled by setting to None)
@@ -363,7 +368,7 @@ class GUI:
 class MESSAGES:
 	CUSTOM_MSG_SHOW_DELAY = 6 # delay between messages when passing more than one
 	CUSTOM_MSG_VISIBLE_FOR = 90 # after this time the msg gets removed from screen
-	LOGBOOK_DEFAULT_DELAY = 4 # delay between condition fulfilled and logbook popping up
+	LOGBOOK_DEFAULT_DELAY = 1 # delay between condition fulfilled and logbook popping up
 
 # AI values read from the command line; use the values below unless overridden by the CLI or the GUI
 class AI:
@@ -484,8 +489,10 @@ class PATHS:
 	ACTION_SETS_JSON_FILE = os.path.join("content", "actionsets.json")
 	TILE_SETS_JSON_FILE = os.path.join("content", "tilesets.json")
 
+	SETTINGS_TEMPLATE_FILE = os.path.join("content", "settings-template.xml")
 	CONFIG_TEMPLATE_FILE = os.path.join("content", "settings-template.xml")
 
+
 	DB_FILES = tuple(os.path.join("content", i) for i in
 	                 ("game.sql", "balance.sql", "names.sql"))
 
@@ -501,6 +508,12 @@ class PATHS:
 	#voice paths
 	VOICE_DIR = os.path.join("content", "audio", "voice")
 
+class SETTINGS:
+	UH_MODULE = "unknownhorizons"
+	FIFE_MODULE = "FIFE"
+	KEY_MODULE = "keys"
+	META_MODULE = "meta"
+
 class PLAYER:
 	STATS_UPDATE_FREQUENCY = GAME_SPEED.TICKS_PER_SECOND
 
@@ -520,6 +533,7 @@ class NETWORK:
 	CLIENT_ADDRESS = None
 	UPDATE_FILE_URL = "http://updates.unknown-horizons.org/current_version.php"
 
+
 ## TRANSLATIONS
 class _LanguageNameDict(dict):
 	def __getitem__(self, key):
