@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -20,44 +20,35 @@
 # 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # ###################################################
 
-import os
-import shutil
-import sys
 import locale
+import logging
 
 from fife import fife
-from fife.extensions.basicapplication import ApplicationBase
-from fife.extensions import pychan
-from fife.extensions.serializers.simplexml import SimpleXMLSerializer
-from fife.extensions.fife_settings import FIFE_MODULE
+from fife.extensions import pychan, fifelog
 
-from horizons.constants import LANGUAGENAMES, PATHS
-from horizons.engine import UH_MODULE, KEY_MODULE
+from horizons.constants import LANGUAGENAMES, PATHS, SETTINGS
 from horizons.engine.pychan_util import init_pychan
-from horizons.engine.settingshandler import SettingsHandler, get_screen_resolutions
-from horizons.engine.settingsdialog import SettingsDialog
+from horizons.engine.settings import Settings
 from horizons.engine.sound import Sound
 from horizons.util.loaders.sqliteanimationloader import SQLiteAnimationLoader
 from horizons.util.loaders.sqliteatlasloader import SQLiteAtlasLoader
 
 
-class Fife(ApplicationBase):
+class Fife(object):
 	"""
 	Basic initiation of engine. Followed later by init().
 	"""
+	log = logging.getLogger('engine.engine')
+
 	def __init__(self):
 		self.pump = []
 
-		self._setting_handler = SettingsHandler(self)
-		self._setup_settings()
-		self._set_window_icon()
-
+		self._setting = Settings(PATHS.USER_CONFIG_FILE, PATHS.SETTINGS_TEMPLATE_FILE)
 		self.engine = fife.Engine()
 		self.engine_settings = self.engine.getSettings()
 
-		super(Fife, self).initLogging()
-
-		self.loadSettings()
+		self.init_logging()
+		self.load_settings()
 
 		self.pychan = pychan
 
@@ -66,88 +57,79 @@ class Fife(ApplicationBase):
 		self.return_values = None
 		self._got_inited = False
 
+	def load_settings(self):
+		"""
+		Load the settings from a python file and load them into the engine.
+		Called in the ApplicationBase constructor.
+		"""
+		# get finalSetting (from the xml file, or if absent the default value)
+		self._finalSetting = self._setting.get_module_settings("FIFE")
 
-	# existing settings not part of this gui or the fife defaults
-	# (required for preserving values when upgrading settings file)
-	UNREFERENCED_SETTINGS = {UH_MODULE: ["Nickname", "AIPlayers", "ClientID"]}
+		self.engine_settings = self.engine.getSettings()
 
-	def _set_window_icon(self):
-		"""Use different window icon for Mac."""
-		if sys.platform == 'darwin':
-			if self.get_fife_setting('WindowIcon') == PATHS.DEFAULT_WINDOW_ICON_PATH:
-				self.set_fife_setting('WindowIcon', PATHS.MAC_WINDOW_ICON_PATH)
+		self.engine_settings.setDefaultFontPath(self._finalSetting['Font'])
+		self.engine_settings.setBitsPerPixel(self._finalSetting['BitsPerPixel'])
+		self.engine_settings.setInitialVolume(self._finalSetting['InitialVolume'])
+		self.engine_settings.setSDLRemoveFakeAlpha(self._finalSetting['SDLRemoveFakeAlpha'])
+		self.engine_settings.setGLCompressImages(self._finalSetting['GLCompressImages'])
+		self.engine_settings.setGLUseFramebuffer(self._finalSetting['GLUseFramebuffer'])
+		self.engine_settings.setGLUseNPOT(self._finalSetting['GLUseNPOT'])
+		(width, height) = self._finalSetting['ScreenResolution'].split('x')
+		self.engine_settings.setScreenWidth(int(width))
+		self.engine_settings.setScreenHeight(int(height))
+		self.engine_settings.setRenderBackend(self._finalSetting['RenderBackend'])
+		self.engine_settings.setFullScreen(self._finalSetting['FullScreen'])
+		self.engine_settings.setLightingModel(self._finalSetting['Lighting'])
 
-	def _setup_settings(self, check_file_version=True):
-		# NOTE: SimpleXMLSerializer can't handle relative paths, it fails silently
-		# (although the doc states otherwise) - thus translate paths to absolute ones
-		_template_config_file = os.path.join(os.getcwd(), PATHS.CONFIG_TEMPLATE_FILE)
-		template_config_parser = SimpleXMLSerializer(_template_config_file)
-		template_settings_version = template_config_parser.get("meta", "SettingsVersion")
-		self._default_hotkeys = template_config_parser.getAllSettings(KEY_MODULE)
+		try:
+			self.engine_settings.setColorKeyEnabled(self._finalSetting['ColorKeyEnabled'])
+		except:
+			pass
 
-		_user_config_file = os.path.join(os.getcwd(), PATHS.USER_CONFIG_FILE)
-		if check_file_version and os.path.exists(_user_config_file):
-			# check if user settings file is the current one
-			user_config_parser = SimpleXMLSerializer(_user_config_file)
-			user_settings_version = user_config_parser.get("meta", "SettingsVersion", -1)
+		try:
+			self.engine_settings.setColorKey(self._finalSetting['ColorKey'][0],self._finalSetting['ColorKey'][1],self._finalSetting['ColorKey'][2])
+		except:
+			pass
 
-			if template_settings_version > user_settings_version: # we have to update the file
-				print 'Discovered old settings file, auto-upgrading: %s -> %s' % \
-				      (user_settings_version, template_settings_version)
-				# create settings so we have a list of all settings
-				self._setup_settings(check_file_version=False)
+		try:
+			self.engine_settings.setWindowTitle(self._finalSetting['WindowTitle'])
+			self.engine_settings.setWindowIcon(self._finalSetting['WindowIcon'])
+		except:
+			pass
 
-				# save settings here
-				entries = []
+		try:
+			self.engine_settings.setFrameLimitEnabled(self._finalSetting['FrameLimitEnabled'])
+			self.engine_settings.setFrameLimit(self._finalSetting['FrameLimit'])
+		except:
+			pass
 
-				# need safe default value
-				default_value = object()
+		try:
+			self.engine_settings.setMouseSensitivity(self._finalSetting['MouseSensitivity'])
+		except:
+			pass
 
-				def update_value(modulename, entryname):
-					# retrieve values from loaded settings file
-					try:
-						value = self._setting.get(modulename, entryname, default_value)
-					except UnicodeEncodeError: # this can happen when unicode data is saved as str
-						value = "default"
-					if value is not default_value:
-						entries.append( (modulename, entryname, value) )
+		try:
+			self.engine_settings.setMouseAccelerationEnabled(self._finalSetting['MouseAcceleration'])
+		except:
+			pass
 
-				# collect values from known settings and unreferenced settings
-				for modulename, module in self._setting.entries.iteritems():
-					for entryname in module.iterkeys():
-						update_value(modulename, entryname)
-				for modulename, entry_list in self.UNREFERENCED_SETTINGS.iteritems():
-					for entryname in entry_list:
-						update_value(modulename, entryname)
+	def init_logging(self):
+		"""Initialize the LogManager."""
 
-				# patch old values
-				if user_settings_version <= 10:
-					old_entries = entries
-					entries = []
-					for i in old_entries:
-						if i[0] == UH_MODULE and i[1] == "Language":
-							entries.append( (i[0], i[1], LANGUAGENAMES.get_by_value(i[2])) )
-						else:
-							entries.append(i)
+		logmodules = self._setting.get(SETTINGS.FIFE_MODULE, "LogModules", ["controller"])
 
-				# write actual new file
-				shutil.copy(PATHS.CONFIG_TEMPLATE_FILE, PATHS.USER_CONFIG_FILE)
-				user_config_parser = SimpleXMLSerializer(_user_config_file)
-				for modulename, entryname, value in entries:
-					user_config_parser.set(modulename, entryname, value)
-				user_config_parser.save()
+		#log to both the console and log file
+		self._log = fifelog.LogManager(self.engine,
+									   self._setting.get(SETTINGS.FIFE_MODULE, "LogToPrompt", "0"),
+									   self._setting.get(SETTINGS.FIFE_MODULE, "LogToFile", "0"))
 
-		self._setting = SettingsDialog(app_name=UH_MODULE,
-		                               settings_file=PATHS.USER_CONFIG_FILE,
-		                               settings_gui_xml="settings.xml",
-		                               changes_gui_xml="requirerestart.xml",
-		                               default_settings_file=PATHS.CONFIG_TEMPLATE_FILE)
+		self._log.setLevelFilter(self._setting.get(SETTINGS.FIFE_MODULE, "LogLevelFilter", fife.LogManager.LEVEL_DEBUG))
 
-		self._setting_handler.add_settings()
+		if logmodules:
+			self._log.setVisibleModules(*logmodules)
 
 	def init(self):
-		"""Second initialization stage of engine
-		"""
+		"""Second initialization stage of engine"""
 		self.engine.init()
 
 		#init stuff
@@ -174,8 +156,7 @@ class Fife(ApplicationBase):
 		self.pychan.init(self.engine, debug_pychan) # pychan debug mode may have performance impacts
 
 		init_pychan()
-
-		self._setting_handler.apply_settings()
+		self._setting.apply()
 
 		self._got_inited = True
 
@@ -187,55 +168,67 @@ class Fife(ApplicationBase):
 		else:
 			self.animationloader = SQLiteAnimationLoader()
 
-	def show_settings(self):
-		"""Show fife settings gui"""
-		if not hasattr(self, "_settings_extra_inited"):
-			self._setting_handler.setup_setting_extras()
-			self._settings_extra_inited = True
-		self._setting.onOptionsPress()
-
 	def set_cursor_image(self, which="default"):
 		"""Sets a certain cursor image.
 		See definition of cursor_images for reference."""
 		self.cursor.set(self.cursor_images[which])
 
 	def get_fife_setting(self, settingname):
-		return self._setting.get(FIFE_MODULE, settingname)
+		return self._setting.get(SETTINGS.FIFE_MODULE, settingname)
 
 	def set_fife_setting(self, settingname, value):
 		"""Probably saves setting in memory. Call save_settings() later"""
-		return self._setting.set(FIFE_MODULE, settingname, value)
+		return self._setting.set(SETTINGS.FIFE_MODULE, settingname, value)
 
 	def get_uh_setting(self, settingname):
-		return self._setting.get(UH_MODULE, settingname)
+		return self._setting.get(SETTINGS.UH_MODULE, settingname)
 
 	def set_uh_setting(self, settingname, value):
 		"""Probably saves setting in memory. Call save_settings() later"""
-		self._setting.set(UH_MODULE, settingname, value)
+		self._setting.set(SETTINGS.UH_MODULE, settingname, value)
 
 	def get_hotkey_settings(self):
-		return self._setting.getSettingsFromFile(KEY_MODULE)
+		return self._setting.get_module_settings(SETTINGS.KEY_MODULE)
 
 	def get_keys_for_action(self, action, default=False):
 		"""Returns list of current hotkeys for *action* or its default hotkeys."""
 		if default:
-			keys = self._default_hotkeys.get(action)
+			keys = self._setting.get_module_template_settings(SETTINGS.KEY_MODULE).get(action)
 		else:
-			keys = self._setting.get(KEY_MODULE, action)
-		return sorted(keys, key=len)
+			keys = self._setting.get(SETTINGS.KEY_MODULE, action)
+		return keys
 
 	def set_key_for_action(self, action, newkey):
 		"""Replaces all existing hotkeys for *action* with *newkey*."""
-		self._setting.set(KEY_MODULE, action, newkey)
+		self._setting.set(SETTINGS.KEY_MODULE, action, newkey)
 
 	def add_key_for_action(self, action, addkey):
 		"""Adds hotkey *addkey* to list of hotkeys for action *action*."""
-		old_keys = self._setting.get(KEY_MODULE, action, defaultValue=[])
+		old_keys = self._setting.get(SETTINGS.KEY_MODULE, action, [])
 		new_keys = set(old_keys + [addkey])
 		self.set_key_for_action(action, list(new_keys))
 
+	def remove_key_for_action(self, action, remkey):
+		"""Removes hotkey *remkey* from list of hotkeys for action *action*."""
+		old_keys = self._setting.get(SETTINGS.KEY_MODULE, action, [])
+		if remkey in old_keys:
+				old_keys.remove(remkey)
+		if len(old_keys) == 0:
+				print 'Cannot have no binding for action'
+				return
+		self.set_key_for_action(action, old_keys)
+
+	def replace_key_for_action(self, action, oldkey, newkey):
+		"""Replaces key *oldkey* with key *newkey* for action *action*"""
+		old_keys = self._setting.get(SETTINGS.KEY_MODULE, action, [])
+		if not oldkey in old_keys:
+			return
+		index = old_keys.index(oldkey)
+		old_keys[index] = newkey
+		self.set_key_for_action(action, old_keys)
+
 	def save_settings(self):
-		self._setting.saveSettings()
+		self._setting.save()
 
 	def play_sound(self, emitter, soundfile):
 		"""Plays a soundfile on the given emitter.
@@ -244,10 +237,10 @@ class Fife(ApplicationBase):
 		self.sound.play_sound(emitter, soundfile)
 
 	def get_locale(self):
-		for locale_code, langname in LANGUAGENAMES.items():
-			if langname == self.get_uh_setting('Language'):
-				if not langname == 'System default':
-					return locale_code
+		langname = self.get_uh_setting('Language')
+		locale_code = LANGUAGENAMES.get_by_value(langname)
+		if not langname == 'System default':
+				return locale_code
 		try:
 			default_locale, default_encoding = locale.getdefaultlocale()
 			return default_locale.split('_')[0]
@@ -258,22 +251,14 @@ class Fife(ApplicationBase):
 			return "en"
 
 	def run(self):
-		"""
-		"""
 		assert self._got_inited
 
-		# Screen Resolutions can only be queried after the engine has been inited
-		available_resolutions = get_screen_resolutions(self.get_fife_setting('ScreenResolution'))
-		self._setting.entries[FIFE_MODULE]['ScreenResolution'].initialdata = available_resolutions
-
 		self.engine.initializePumping()
 		self.loop()
 		self.engine.finalizePumping()
 		self.__kill_engine()
 
 	def loop(self):
-		"""
-		"""
 		while not self.quit_requested:
 			try:
 				self.engine.pump()
@@ -292,13 +277,17 @@ class Fife(ApplicationBase):
 		self.engine.destroy()
 
 	def breakLoop(self, returnValue=None):
-		"""
-		@param returnValue:
-		"""
 		self.return_values = returnValue
 		self.break_requested = True
 
 	def quit(self):
-		""" Quits the engine.
-		"""
+		"""Quits the engine."""
 		self.quit_requested = True
+
+	@classmethod
+	def getVersion(cls):
+		"""Returns a tuple (Major, Minor, Patch) version of the current running Fife."""
+		try:
+			return (fife.getMajor(), fife.getMinor(), fife.getPatch())
+		except AttributeError:
+			return (0, 0, 0)
