@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -40,6 +40,7 @@ class Sound(object):
 		self.emitter['bgsound'] = None
 		self.emitter['effects'] = None
 		self.emitter['speech'] = None
+		self.emitter['ambient'] = []
 
 		#temporarily select a random music file to play. TODO: Replace with proper playlist
 		self.ingame_music = glob.glob('content/audio/music/*.ogg')
@@ -77,27 +78,26 @@ class Sound(object):
 
 	def enable_sound(self):
 		"""Enable all sound and start playing music."""
-		if self.engine.get_fife_setting("PlaySounds"): # Set up sound if it is enabled
-			self.soundmanager = self.engine.engine.getSoundManager()
-			self.soundmanager.init()
+		# Set up sound if it is enabled
+		self.soundmanager = self.engine.engine.getSoundManager()
+		self.soundmanager.init()
 
-			self.soundclipmanager = self.engine.engine.getSoundClipManager()
-			self.emitter['bgsound'] = self.soundmanager.createEmitter()
-			self.emitter['bgsound'].setGain(self.engine.get_uh_setting("VolumeMusic"))
-			self.emitter['bgsound'].setLooping(False)
-			self.emitter['effects'] = self.soundmanager.createEmitter()
-			self.emitter['effects'].setGain(self.engine.get_uh_setting("VolumeEffects"))
-			self.emitter['effects'].setLooping(False)
-			self.emitter['speech'] = self.soundmanager.createEmitter()
-			self.emitter['speech'].setGain(self.engine.get_uh_setting("VolumeEffects"))
-			self.emitter['speech'].setLooping(False)
-			self.emitter['ambient'] = []
+		self.soundclipmanager = self.engine.engine.getSoundClipManager()
+		self.emitter['bgsound'] = self.soundmanager.createEmitter()
+		self.emitter['bgsound'].setGain(self.engine.get_uh_setting("VolumeMusic"))
+		self.emitter['bgsound'].setLooping(False)
+		self.emitter['effects'] = self.soundmanager.createEmitter()
+		self.emitter['effects'].setGain(self.engine.get_uh_setting("VolumeEffects"))
+		self.emitter['effects'].setLooping(False)
+		self.emitter['speech'] = self.soundmanager.createEmitter()
+		self.emitter['speech'].setGain(self.engine.get_uh_setting("VolumeEffects"))
+		self.emitter['speech'].setLooping(False)
 
-			# Start background music:
-			self._old_byte_pos = 0.0
-			self._old_smpl_pos = 0.0
-			self.check_music(refresh_playlist=True, play_menu_tracks=True)
-			ExtScheduler().add_new_object(self.check_music, self, loops=-1)
+		# Start background music:
+		self._old_byte_pos = 0.0
+		self._old_smpl_pos = 0.0
+		self.check_music(refresh_playlist=True, play_menu_tracks=True)
+		ExtScheduler().add_new_object(self.check_music, self, loops=-1)
 
 	def disable_sound(self):
 		"""Disable all sound outputs."""
@@ -145,11 +145,39 @@ class Sound(object):
 		@param emitter: string: name of emitter that is to play the sound
 		@param soundfile: string: path to the sound file we want to play
 		"""
+		if not self.engine.get_fife_setting("PlaySounds"):
+			return
+		emitter = self.emitter[emitter]
+		#TODO what do we need those two asserts for...
+		assert emitter is not None, "You need to supply an initialized emitter"
+		assert soundfile is not None, "You need to supply a soundfile"
+		emitter.reset()
+		#TODO remove str() -- http://fife.trac.cloudforge.com/engine/ticket/449
+		emitter.setSoundClip(self.soundclipmanager.load(str(soundfile)))
+		emitter.play()
+
+	def set_volume_emitter(self, emitter, volume):
+		"""Sets the volume on the emitter specified by emitter_name.
+		@param emitter: string with the emitters name, used as key for the self.emitter dict
+		@param volume: double which volume the emitter is to be set to range[0, 1]
+		"""
 		if self.engine.get_fife_setting("PlaySounds"):
-			emitter = self.emitter[emitter]
-			assert emitter is not None, "You need to supply an initialized emitter"
-			assert soundfile is not None, "You need to supply a soundfile"
-			emitter.reset()
-			#TODO remove str() -- http://fife.trac.cloudforge.com/engine/ticket/449
-			emitter.setSoundClip(self.soundclipmanager.load(str(soundfile)))
-			emitter.play()
+			self.emitter[emitter].setGain(volume)
+
+	def set_volume_bgmusic(self, volume):
+		"""Sets the volume for the backgroundmusic.
+		@param volume: double which volume the emitter is to be set to range[0, 1]
+		"""
+		self.set_volume_emitter('bgsound', volume)
+
+	def set_volume_effects(self, volume):
+		"""Sets the volume for the effects, speech and ambient sounds.
+		@param volume: double which volume the emitter is to be set to range[0, 1]
+		"""
+		self.set_volume_emitter('effects', volume)
+		self.set_volume_emitter('speech', volume)
+		for emitter in self.emitter['ambient']:
+				emitter.setGain(volume*2)
+
+
+
