@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -28,7 +28,7 @@ from horizons.constants import BUILDINGS, GAME_SPEED, VERSION, LAYERS, VIEW
 from horizons.entities import Entities
 from horizons.gui import mousetools
 from horizons.gui.keylisteners import IngameKeyListener, KeyConfig
-from horizons.gui.modules import PauseMenu, HelpDialog
+from horizons.gui.modules import PauseMenu, HelpDialog, SelectSavegameDialog
 from horizons.gui.modules.ingame import ChatDialog, ChangeNameDialog, CityInfo
 from horizons.gui.tabs import TabWidget, BuildTab, DiplomacyTab, SelectMultiTab, MainSquareOverviewTab
 from horizons.gui.tabs.tabinterface import TabInterface
@@ -77,6 +77,8 @@ class IngameGui(LivingObject):
 
 		# Windows
 		self.windows = WindowManager()
+		self.show_popup = self.windows.show_popup
+		self.show_error_popup = self.windows.show_error_popup
 
 		self.logbook = LogBook(self.session, self.windows)
 		self.players_overview = PlayersOverview(self.session)
@@ -191,6 +193,10 @@ class IngameGui(LivingObject):
 
 		super(IngameGui, self).end()
 
+	def show_select_savegame(self, mode):
+		window = SelectSavegameDialog(mode, self.windows)
+		return self.windows.show(window)
+
 	def toggle_pause(self):
 		self.windows.toggle(self.pausemenu)
 
@@ -317,7 +323,7 @@ class IngameGui(LivingObject):
 
 		if not self.session.is_game_loaded():
 			# Fire a message for new world creation
-			self.session.ingame_gui.message_widget.add(point=None, string_id='NEW_WORLD')
+			self.session.ingame_gui.message_widget.add('NEW_WORLD')
 
 		# Show message when the relationship between players changed
 		def notify_change(caller, old_state, new_state, a, b):
@@ -346,6 +352,12 @@ class IngameGui(LivingObject):
 
 		return True
 
+	def on_return(self):
+		if self.windows.visible:
+			self.windows.on_return()
+
+		return True
+
 	def _on_speed_changed(self, message):
 		self._display_speed(message.new)
 
@@ -386,6 +398,8 @@ class IngameGui(LivingObject):
 
 		if action == _Actions.ESCAPE:
 			return self.on_escape()
+		elif keyval == fife.Key.ENTER:
+			return self.on_return()
 
 		if action == _Actions.GRID:
 			gridrenderer = self.session.view.renderer['GridRenderer']
@@ -531,7 +545,7 @@ class IngameGui(LivingObject):
 
 	def _on_new_disaster(self, message):
 		"""Called when a building is 'infected' with a disaster."""
-		if message.building.owner.is_local_player:
+		if message.building.owner.is_local_player and len(message.disaster._affected_buildings) == 1:
 			pos = message.building.position.center
 			self.message_widget.add(point=pos, string_id=message.disaster_class.NOTIFICATION_TYPE)
 
