@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -66,6 +66,9 @@ class EditorStartMenu(Window):
 		self._right_side.show()
 		self._gui.show()
 
+	def on_return(self):
+		self.act()
+
 	def hide(self):
 		self._gui.hide()
 
@@ -84,7 +87,6 @@ class EditorCreateMapWidget(object):
 
 		for size in self.sizes:
 			option_name = 'size_%d' % size
-			#xgettext:python-format
 			# size of empty map in map editor
 			self._gui.findChild(name=option_name).text = _('{size}x{size} tiles').format(size=size)
 
