@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -70,14 +70,23 @@ class PlayerDataSelection(object):
 	def set_color(self, color_id):
 		"""Updates the background color of large label where players
 		see their currently chosen color. Stores result in settings.
-		@param color_id: int. Gets converted to FIFE Color object.
+		@param color_id: int. Gets converted to util.Color object.
 		"""
-		self.selected_color = Color[color_id]
+		try:
+			self.selected_color = Color[color_id]
+		except KeyError:
+			# For some reason, color_id can be 0 apparently:
+			# http://forum.unknown-horizons.org/viewtopic.php?t=6927
+			# Reset that setting to 1 if the problem occurs.
+			color_id = 1
+			self.selected_color = Color[color_id]
 		horizons.globals.fife.set_uh_setting("ColorID", color_id)
-		self.gui.findChild(name='selectedcolor').background_color = Color[color_id]
+		horizons.globals.fife.save_settings()
+		self.gui.findChild(name='selectedcolor').background_color = self.selected_color
 
 	def set_player_name(self, playername):
 		horizons.globals.fife.set_uh_setting("Nickname", playername)
+		horizons.globals.fife.save_settings()
 		self.gui.distributeData({
 			'playername': unicode(playername),
 			})
