@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -144,7 +144,7 @@ class BuildingTool(NavigationTool):
 	def highlight_buildable(self, tiles_to_check=None, new_buildings=True):
 		"""Highlights all buildable tiles and select buildings that are inversely related in order to show their range.
 		@param tiles_to_check: list of tiles to check for coloring.
-		@param new_buildings: Set to true if you have set tiles_to_check and there are new buildings. An internal structure for optimization will be amended."""
+		@param new_buildings: Set to True if you have set tiles_to_check and there are new buildings. An internal structure for optimization will be amended."""
 		self._build_logic.highlight_buildable(self, tiles_to_check)
 
 		# Also distinguish inversely related buildings (lumberjack for tree).
@@ -227,7 +227,6 @@ class BuildingTool(NavigationTool):
 		self.__class__.gui.mapEvents( { "rotate_left" : self.rotate_left,
 		                                "rotate_right": self.rotate_right } )
 		# set translated building name in gui
-		#xgettext:python-format
 		self.__class__.gui.findChild(name='headline').text = _('Build {building}').format(building=_(self._class.name))
 		self.__class__.gui.findChild(name='running_costs').text = unicode(self._class.running_costs)
 		head_box = self.__class__.gui.findChild(name='head_box')
@@ -240,9 +239,10 @@ class BuildingTool(NavigationTool):
 
 	def draw_gui(self):
 		if not hasattr(self, "action_set"):
-			level = self.session.world.player.settler_level if \
-				not hasattr(self._class, "default_level_on_build") else \
-				self._class.default_level_on_build
+			try:
+				level = self._class.default_level_on_build
+			except AttributeError:
+				level = self.session.world.player.settler_level
 			action_set = self._class.get_random_action_set(level=level)
 		action_sets = ActionSetLoader.get_sets()
 		for action_option in ['idle', 'idle_full', 'abcd']:
@@ -528,7 +528,7 @@ class BuildingTool(NavigationTool):
 				BuildingTool._last_road_built.append(now)
 				if len(BuildingTool._last_road_built) > 2:
 					if (now - BuildingTool._last_road_built[-3]) < 1.2:
-						self.session.ingame_gui.message_widget.add(point=None, string_id="DRAG_ROADS_HINT")
+						self.session.ingame_gui.message_widget.add('DRAG_ROADS_HINT')
 						# don't display hint multiple times at the same build situation
 						BuildingTool._last_road_built = []
 					BuildingTool._last_road_built = BuildingTool._last_road_built[-3:]
@@ -705,7 +705,7 @@ class BuildingTool(NavigationTool):
 
 
 class ShipBuildingToolLogic(object):
-	"""Helper class to seperate the logic needed when building from a ship from
+	"""Helper class to separate the logic needed when building from a ship from
 	the main building tool."""
 
 	def __init__(self, ship):
@@ -760,7 +760,7 @@ class ShipBuildingToolLogic(object):
 	def continue_build(self): pass
 
 class SettlementBuildingToolLogic(object):
-	"""Helper class to seperate the logic needen when building from a settlement
+	"""Helper class to separate the logic needen when building from a settlement
 	from the main building tool"""
 
 	def __init__(self, building_tool):
