@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -19,7 +19,12 @@
 # 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # ###################################################
 
-from fife.fife import Color
+try:
+	#TODO fifechan / FIFE 0.3.5+ compat
+	from fife.fifechan import Color
+except ImportError:
+	# this is the old (0.3.4 and earlier) API
+	from fife.fife import Color
 
 BROWN = { 64: Color(80, 80, 40,  64),
           96: Color(80, 80, 40,  96),
@@ -100,12 +105,6 @@ STYLES = {
 		},
 },
 
-'city_info': { # style for city info
-		'default': {
-			'font': 'cityinfo',
-		},
-},
-
 'headline': { # style for headlines
 		'default': {
 			'font': 'headline',
