@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -50,7 +50,7 @@ class TabWidget(object):
 		self._tabs = [] if not tabs else tabs
 		self.current_tab = self._tabs[0] # Start with the first tab
 		self.widget = load_uh_widget("tab_base.xml")
-		self.widget.position_technique = 'right-239:top+207'
+		self.widget.position_technique = 'right-239:top+209'
 		self.content = self.widget.findChild(name='content')
 		self._init_tabs()
 		# select a tab to show (first one is default)
@@ -80,7 +80,7 @@ class TabWidget(object):
 				background.image = tab.button_background_image
 				button.path = tab.path
 			button.capture(Callback(self._show_tab, index))
-			if hasattr(tab, 'helptext') and tab.helptext is not None:
+			if hasattr(tab, 'helptext') and tab.helptext:
 				button.helptext = tab.helptext
 			container.size = background.size
 			container.addChild(background)
