@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -52,6 +52,7 @@ class LogBook(PickBeltWidget, Window):
 
 	def __init__(self, session, windows):
 		self.statistics_index = [i for i, sec in self.sections].index('statistics')
+		self.logbook_index = [i for i, sec in self.sections].index('logbook')
 		self._page_ids = {} # dict mapping self._cur_entry to message.msgcount
 		super(LogBook, self).__init__()
 		self.session = session
@@ -213,8 +214,13 @@ class LogBook(PickBeltWidget, Window):
 			for image in parameter[1]:
 				add.addChild(Icon(image=str(image)))
 		elif parameter_type == u'Headline':
-			add = Label(text=unicode(parameter[1]), wrap_text=True,
-			            min_size=(335, 0), max_size=(335, 508), font='headline')
+			add = HBox()
+			is_not_last_headline = self._parameters and self._cur_entry < (len(self._parameters) - 2)
+			if is_not_last_headline:
+				add.addChild(Icon(image="content/gui/images/tabwidget/done.png"))
+
+			add.addChild(Label(text=unicode(parameter[1]), wrap_text=True,
+			            min_size=(335, 0), max_size=(335, 508), font='headline'))
 		elif parameter_type == u'BoldLabel':
 			add = Label(text=unicode(parameter[1]), wrap_text=True,
 			            min_size=(335, 0), max_size=(335, 508), font='14_bold')
@@ -224,7 +230,10 @@ class LogBook(PickBeltWidget, Window):
 			# duplicate_message stops messages from
 			# being duplicated on page reload.
 			message = parameter[1]
-			duplicate_message = message in self._messages_to_display # message is already going to be displayed
+			# message is already going to be displayed or has been displayed
+			# before (e.g. re-opening older logbook pages)
+			duplicate_message = (message in self._messages_to_display or  
+								message in self._message_log)
 
 			if not duplicate_message:
 				self._messages_to_display.append(message) # the new message has not been displayed
@@ -268,6 +277,10 @@ class LogBook(PickBeltWidget, Window):
 			"""
 			return [list(l[1]) for l in groupby(parameters, lambda x: x != ['Pagebreak']) if l[0]]
 
+		# If a scenario goal has been completed, remove the corresponding message
+		for message in self._displayed_messages:
+			self.session.ingame_gui.message_widget.remove(message)
+
 		self._displayed_messages = [] # Reset displayed messages
 		for parameter_list in _split_on_pagebreaks(parameters):
 			self._parameters.append(parameter_list)
@@ -284,6 +297,7 @@ class LogBook(PickBeltWidget, Window):
 		if show_logbook and hasattr(self, "_gui"):
 			self._redraw_captainslog()
 			self._windows.show(self)
+			self.show_logbookwidget()
 
 	def clear(self):
 		"""Remove all entries"""
@@ -311,6 +325,11 @@ class LogBook(PickBeltWidget, Window):
 		AmbientSoundComponent.play_special('flippage')
 		self._redraw_captainslog()
 
+	def show_logbookwidget(self):
+		"""Shows logbook with Logbook page selected"""
+		if self.current_mode != self.logbook_index:
+			self.update_view(self.logbook_index)
+
 ########
 #        STATISTICS  SUBWIDGET
 ########
