@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -33,70 +33,55 @@ We will need to make gettext recognize namespaces some time, but hardcoded
 
 import platform
 import gettext
+import glob
 import os
 import logging
 import locale
-import weakref
 
 import horizons.globals
 
-from horizons.constants import LANGUAGENAMES
-from horizons.i18n import objecttranslations, guitranslations, quotes
-from horizons.i18n.utils import get_fontdef_for_locale, find_available_languages
+from horizons.constants import LANGUAGENAMES, FONTDEFS
+from horizons.ext.speaklater import make_lazy_gettext
 from horizons.messaging import LanguageChanged
 
 log = logging.getLogger("i18n")
 
-# save translated widgets
-translated_widgets = {}
 
-def translate_widget(untranslated, filename):
-	"""
-	Load widget translations from guitranslations.py file.
-	Its entries look like {element_name: (attribute, translation)}.
-	The translation is not applied to inactive widgets.
-	Check update_all_translations for the application.
-	"""
-	global translated_widgets
-	if filename in guitranslations.text_translations:
-		for entry in guitranslations.text_translations[filename].iteritems():
-			widget = untranslated.findChild(name=entry[0][0])
-			if widget is not None:
-				replace_attribute(widget, entry[0][1], entry[1])
-				widget.adaptLayout()
-	else:
-		log.debug('No translation key in i18n.guitranslations for file %s', filename)
+LANGCACHE = {}
 
-	# save as weakref for updates to translations
-	translated_widgets[filename] = weakref.ref(untranslated)
+def find_available_languages(domain='unknown-horizons', update=False):
+	"""Returns a dict( lang_key -> locale_dir )"""
+	global LANGCACHE
+	if LANGCACHE and not update:
+		return LANGCACHE
 
-	return untranslated
+	alternatives = ('content/lang',
+	                'build/mo',
+	                '/usr/share/locale',
+	                '/usr/share/games/locale',
+	                '/usr/local/share/locale',
+	                '/usr/local/share/games/locale')
+
+	LANGCACHE = languages = {}
+
+	for i in alternatives:
+		for j in glob.glob('%s/*/*/%s.mo' % (i, domain)):
+			splited = j.split(os.sep)
+			key = splited[-3]
+			if not key in languages:
+				languages[key] = os.sep.join(splited[:-3])
+
+	# there's always a default, which is english
+	languages[LANGUAGENAMES['']] = ''
+	languages['en'] = ''
+
+	return languages
 
 
-def update_all_translations():
-	"""Update the translations in every active widget"""
-	global translated_widgets
-	guitranslations.set_translations()
-	objecttranslations.set_translations()
-	quotes.set_translations()
-	for (filename, widget) in translated_widgets.iteritems():
-		widget = widget() # resolve weakref
-		if not widget:
-			continue
-		all_widgets = guitranslations.text_translations.get(filename, {})
-		for (element_name, attribute), translation in all_widgets.iteritems():
-			element = widget.findChild(name=element_name)
-			replace_attribute(element, attribute, translation)
-			#NOTE pychan + reloading font = ???
-			element.font = element.font
-		widget.adaptLayout()
-
-
-def replace_attribute(widget, attribute, text):
-	if hasattr(widget, attribute):
-		setattr(widget, attribute, text)
-	else:
-		log.warning("Could not replace attribute %s in widget %s", attribute, widget)
+def get_fontdef_for_locale(locale):
+	"""Returns path to the fontdef file for a locale. Unifont is default."""
+	fontdef_file = FONTDEFS.get(locale, 'unifont')
+	return os.path.join('content', 'fonts', u'{0}.fontdef'.format(fontdef_file))
 
 
 def change_language(language=None):
@@ -139,6 +124,7 @@ def change_language(language=None):
 	fontdef = get_fontdef_for_locale(new_locale)
 	horizons.globals.fife.pychan.loadFonts(fontdef)
 
-	# dynamically reset all translations of active widgets
-	update_all_translations()
 	LanguageChanged.broadcast(None)
+
+
+_lazy = make_lazy_gettext(lambda: lambda s: _(s))
