@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -36,6 +36,7 @@ import traceback
 import threading
 from thread import error as ThreadError  # raised by threading.Lock.release
 import subprocess
+import logging
 
 from fife import fife as fife_module
 
@@ -120,6 +121,9 @@ def start(_command_line_arguments):
 			horizons.globals.fife._log.logToPrompt = False
 			horizons.globals.fife._log.logToFile = True
 
+	if horizons.globals.fife.get_uh_setting("DebugLog"):
+		set_debug_log(True, startup=True)
+
 	if command_line_arguments.mp_bind:
 		try:
 			mpieces = command_line_arguments.mp_bind.partition(':')
@@ -145,7 +149,7 @@ def start(_command_line_arguments):
 	                          and horizons.globals.fife.get_uh_setting('AtlasGenerationEnabled') \
 	                          and command_line_arguments.atlas_generation \
 	                          and not command_line_arguments.gui_test:
-		args = [sys.executable, os.path.join('development', 'generate_atlases.py'),
+		args = [sys.executable, os.path.join('horizons', 'engine', 'generate_atlases.py'),
 		        str(horizons.globals.fife.get_uh_setting('MaxAtlasSize'))]
 		atlas_generator = subprocess.Popen(args, stdout=None, stderr=subprocess.STDOUT)
 
@@ -295,6 +299,11 @@ def quit():
 	preload_game_join(preloading)
 	horizons.globals.fife.quit()
 
+def quit_session():
+	"""Quits the current game."""
+	_modules.session = None
+	_modules.gui.show_main()
+
 def start_singleplayer(options):
 	"""Starts a singleplayer game."""
 	_modules.gui.show_loading_screen()
@@ -318,7 +327,7 @@ def start_singleplayer(options):
 		from horizons.spsession import SPSession as session_class
 
 	# start new session
-	_modules.session = session_class(_modules.gui, horizons.globals.db)
+	_modules.session = session_class(horizons.globals.db)
 
 	from horizons.scenario import InvalidScenarioFileFormat # would create import loop at top
 	try:
@@ -370,7 +379,7 @@ def prepare_multiplayer(game, trader_enabled=True, pirate_enabled=True, natural_
 	# get random seed for game
 	uuid = game.uuid
 	random = sum([ int(uuid[i : i + 2], 16) for i in range(0, len(uuid), 2) ])
-	_modules.session = MPSession(_modules.gui, horizons.globals.db, NetworkInterface(), rng_seed=random)
+	_modules.session = MPSession(horizons.globals.db, NetworkInterface(), rng_seed=random)
 
 	# NOTE: this data passing is only temporary, maybe use a player class/struct
 	if game.is_savegame:
@@ -391,7 +400,7 @@ def _start_map(map_name, ai_players=0, is_scenario=False,
                pirate_enabled=True, trader_enabled=True, force_player_id=None, is_map=False):
 	"""Start a map specified by user
 	@param map_name: name of map or path to map
-	@return: bool, whether loading succeded"""
+	@return: bool, whether loading succeeded"""
 	if is_scenario:
 		savegames = SavegameManager.get_available_scenarios(locales=True)
 	else:
@@ -413,7 +422,7 @@ def _start_random_map(ai_players, seed=None, force_player_id=None):
 def _load_cmd_map(savegame, ai_players, force_player_id=None):
 	"""Load a map specified by user.
 	@param savegame: either the displayname of a savegame or a path to a savegame
-	@return: bool, whether loading succeded"""
+	@return: bool, whether loading succeeded"""
 	# first check for partial or exact matches in the normal savegame list
 	savegames = SavegameManager.get_saves()
 	map_file = _find_matching_map(savegame, savegames)
@@ -458,12 +467,12 @@ def _find_matching_map(name_or_path, savegames):
 def _load_last_quicksave(session=None, force_player_id=None):
 	"""Load last quicksave
 	@param session: value of session
-	@return: bool, whether loading succeded"""
+	@return: bool, whether loading succeeded"""
 	save_files = SavegameManager.get_quicksaves()[0]
 	if _modules.session is not None:
 		if not save_files:
-			_modules.session.gui.show_popup(_("No quicksaves found"),
-			                                _("You need to quicksave before you can quickload."))
+			_modules.session.ingame_gui.show_popup(_("No quicksaves found"),
+			                                       _("You need to quicksave before you can quickload."))
 			return False
 	else:
 		if not save_files:
@@ -520,7 +529,7 @@ def edit_game_map(saved_game_name):
 
 def _create_main_db():
 	"""Returns a dbreader instance, that is connected to the main game data dbfiles.
-	NOTE: This data is read_only, so there are no concurrency issues"""
+	NOTE: This data is read_only, so there are no concurrency issues."""
 	_db = UhDbAccessor(':memory:')
 	for i in PATHS.DB_FILES:
 		f = open(i, "r")
@@ -532,7 +541,6 @@ def preload_game_data(lock):
 	"""Preloads game data.
 	Keeps releasing and acquiring lock, runs until lock can't be acquired."""
 	try:
-		import logging
 		from horizons.entities import Entities
 		log = logging.getLogger("preload")
 		mydb = _create_main_db() # create own db reader instance, since it's not thread-safe
@@ -550,7 +558,7 @@ def preload_game_data(lock):
 			lock.release()
 		log.debug("Preloading done.")
 	except Exception as e:
-		log.warning("Exception occured in preloading thread: %s", e)
+		log.warning("Exception occurred in preloading thread: %s", e)
 	finally:
 		if lock.locked():
 			lock.release()
@@ -570,3 +578,35 @@ def preload_game_join(preloading):
 			lock.release()
 		except ThreadError:
 			pass # due to timing issues, the lock might be released already
+
+def set_debug_log(enabled, startup=False):
+	"""
+	@param enabled: boolean if logging should be enabled
+	@param startup: True if on startup to apply settings. Won't show popup
+	"""
+	options = command_line_arguments
+
+	if enabled: # enable logging
+		if options.debug:
+			# log file is already set up, just make sure everything is logged
+			logging.getLogger().setLevel(logging.DEBUG)
+		else: # set up all anew
+			class Data(object):
+				debug = False
+				debug_log_only = True
+				logfile = None
+				debug_module = []
+			# use setup call reference, see run_uh.py
+			options.setup_debugging(Data)
+			options.debug = True
+
+		if not startup:
+			headline = _("Logging enabled")
+			msg = _("Logs are written to {directory}.").format(directory=PATHS.LOG_DIR)
+			# Let the ext scheduler show the popup, so that all other settings can be saved and validated
+			ExtScheduler().add_new_object(Callback(_modules.gui.show_popup, headline, msg), None)
+
+	else: #disable logging
+		logging.getLogger().setLevel(logging.WARNING)
+		# keep debug flag in options so to not reenable it fully twice
+		# on reenable, only the level will be reset
