@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -24,7 +24,7 @@ import logging
 import uuid
 
 from horizons import network
-from horizons.i18n.utils import find_available_languages
+from horizons.i18n import find_available_languages
 from horizons.network import packets, enet
 from horizons.network.common import Player, Game, ErrorType
 
@@ -479,8 +479,10 @@ class Server(object):
 		else:
 			for _player in game.players:
 				if _player.peer.state == enet.PEER_STATE_CONNECTED:
-					self.fatalerror(_player, __("I feel like a bad bunny but one player has terminated the game"
-						" which currently for technical reasons means that the game cannot continue. Sorry :*("))
+					self.fatalerror(_player,
+						__("One player has terminated their game. "
+						"For technical reasons, this currently means the game cannot continue. "
+						"We are very sorry about that."))
 		self.call_callbacks('deletegame', game)
 
 
