@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -188,6 +188,11 @@ def time_passed(session, seconds):
 	"""Returns whether at least *seconds* seconds have passed since the game started."""
 	return (Scheduler().cur_tick >= Scheduler().get_ticks(seconds))
 
+@register()
+def game_started(session):
+	"""Always return True. Used for one-off events"""
+	return True
+
 @register()
 def var_eq(session, variable, value):
 	"""Returns whether *variable* has a value equal to *value*.
@@ -266,4 +271,4 @@ def _building_in_range_of(session, building_class, *classes):
 				for building2 in settlement.buildings_by_id[other_class]: # iterate through all buildings of other_class
 					if building.position.distance( building2.position ) <= building.radius: # building in range of building2
 						return True
-	return False # building not found in range
\ No newline at end of file
+	return False # building not found in range
