@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -27,7 +27,7 @@ from horizons.util.python.weakmethodlist import WeakMethodList
 class ChangeListener(object):
 	"""Trivial ChangeListener.
 	The object that changes and the object that listens have to inherit from this class.
-	An object calls _changed everytime something has changed, obviously.
+	An object calls _changed every time something has changed, obviously.
 	This function calls every Callback, that has been registered to listen for a change.
 	NOTE: ChangeListeners aren't saved, they have to be reregistered on load
 	NOTE: RemoveListeners must not access the object, as it is in progress of being destroyed.
@@ -84,7 +84,7 @@ class ChangeListener(object):
 		assert callable(listener)
 		if not no_duplicates or listener not in self.__listeners:
 			self.__listeners.append(listener)
-		if call_listener_now: # also call if duplicate is adde
+		if call_listener_now: # also call if duplicate is added
 			listener()
 
 	def remove_change_listener(self, listener):
@@ -146,7 +146,7 @@ These methods get added automatically (eventname is the name you pass to the dec
 - has_eventname_listener(listener)
     Checks if a certain listener has been added.
 - on_eventname
-    This is used to call the callbacks when the event occured.
+    This is used to call the callbacks when the event occurred.
     Additional parameters may be provided, which are passed to the callback.
 
 The goal is to simplify adding special listeners, as for example used in the
