@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -19,9 +19,11 @@
 # 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # ###################################################
 
+import platform
 import webbrowser
 import urllib
 import urllib2
+import socket
 
 from fife.extensions.pychan.widgets import Button
 
@@ -41,45 +43,48 @@ def check_for_updates(info):
 	"""Check if there's a new version.
 	@return update file contents or None"""
 	# make sure to always set info.status, but only when we're done
-	if VERSION.IS_DEV_VERSION: # no updates for git version
+	# no updates for git version
+	if VERSION.IS_DEV_VERSION:
 		info.status = UpdateInfo.INVALID
 		return
 
-	# retrieve current version w.r.t. the local version.
-	# this way, possible configurations of different most recent versions should be handleable in the future.
-	data = urllib.urlencode( {"my_version" : VERSION.RELEASE_VERSION} )
-	url = NETWORK.UPDATE_FILE_URL
-	try:
-		u = urllib2.urlopen( url + "?" + data, timeout=TIMEOUT )
-	except urllib2.URLError as e:
-		# Silently ignore the failed update, printing stuff might crash the game
-		# if no console is available
-		info.status = UpdateInfo.INVALID
-		return
+	# only updates for operating systems missing a packagemanagement
+	if (platform.system() == 'Windows' or platform.system() == 'Darwin'):
+		# retrieve current version w.r.t. the local version.
+		# this way, possible configurations of different most recent versions should be handleable in the future.
+		data = urllib.urlencode( {"my_version" : VERSION.RELEASE_VERSION} )
+		url = NETWORK.UPDATE_FILE_URL
+		try:
+			u = urllib2.urlopen( url + "?" + data, timeout=TIMEOUT )
+		except (urllib2.URLError, socket.timeout):
+			# Silently ignore the failed update, printing stuff might crash the game
+			# if no console is available
+			info.status = UpdateInfo.INVALID
+			return
 
-	version = u.readline()
-	link = u.readline()
-	u.close()
+		version = u.readline()
+		link = u.readline()
+		u.close()
 
-	version = version[:-1] # remove newlines
-	link = link[:-1] # remove newlines
+		version = version[:-1] # remove newlines
+		link = link[:-1] # remove newlines
 
-	if version != VERSION.RELEASE_VERSION:
-		# there is a new version
-		info.version = version
-		info.link = link
-		info.status = UpdateInfo.READY
+		if version != VERSION.RELEASE_VERSION:
+			# there is a new version
+			info.version = version
+			info.link = link
+			info.status = UpdateInfo.READY
+		else:
+			info.status = UpdateInfo.INVALID
 	else:
 		info.status = UpdateInfo.INVALID
 
-
 class VersionHint(Popup):
 
 	def __init__(self, windows, info):
 		self.info = info
 
 		title = _("New version of Unknown Horizons")
-		#xgettext:python-format
 		text = _("There is a more recent release of Unknown Horizons ({new_version}) "
 				 "than the one you are currently using ({old_version}).").format(
 				new_version=info.version,
