@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -19,6 +19,7 @@
 # 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 # ###################################################
 
+import logging
 import os
 import os.path
 import json
@@ -27,16 +28,21 @@ import tempfile
 
 from collections import defaultdict
 from sqlite3 import OperationalError
+from yaml.parser import ParserError
 
 from horizons.constants import BUILDINGS, VERSION, UNITS
 from horizons.entities import Entities
 from horizons.util.dbreader import DbReader
 from horizons.util.python import decorators
 from horizons.util.shapes import Rect
+from horizons.util.yamlcache import YamlCache
+
 
 class SavegameUpgrader(object):
 	"""The class that prepares saved games to be loaded by the current version."""
 
+	log = logging.getLogger("util.savegameupgrader")
+
 	def __init__(self, path):
 		super(SavegameUpgrader, self).__init__()
 		self.original_path = path
@@ -190,7 +196,7 @@ class SavegameUpgrader(object):
 		   '"starting_point_y" INTEGER NOT NULL, "target_point_x" INTEGER NOT NULL, "target_point_y" INTEGER NOT NULL, "state" INTEGER NOT NULL )')
 		# SurpriseAttack
 		db('CREATE TABLE "ai_mission_surprise_attack" ("enemy_player_id" INTEGER NOT NULL, "target_point_x" INTEGER NOT NULL, "target_point_y" INTEGER NOT NULL,'
-			'"target_point_radius" INTEGER NOT NULL, "return_point_x" INTEGER NOT NULL, "return_point_y" INTEGER NOT NULL )')
+		   '"target_point_radius" INTEGER NOT NULL, "return_point_x" INTEGER NOT NULL, "return_point_y" INTEGER NOT NULL )')
 		# ChaseShipsAndAttack
 		db('CREATE TABLE "ai_mission_chase_ships_and_attack" ("target_ship_id" INTEGER NOT NULL )')
 
@@ -284,9 +290,8 @@ class SavegameUpgrader(object):
 				settlement_map[coords] = settlement_id
 		db("DELETE FROM settlement_tiles")
 
-		deposits = []
 		for (worldid, building_id, x, y, location_id) in db("SELECT rowid, type, x, y, location FROM building WHERE type = ? OR type = ?",
-			    BUILDINGS.CLAY_DEPOSIT, BUILDINGS.MOUNTAIN):
+				                                            BUILDINGS.CLAY_DEPOSIT, BUILDINGS.MOUNTAIN):
 			worldid = int(worldid)
 			building_id = int(building_id)
 			origin_coords = (int(x), int(y))
@@ -308,7 +313,7 @@ class SavegameUpgrader(object):
 					db("UPDATE building SET location = ? WHERE rowid = ?", settlement_id, worldid)
 
 		# save the new settlement tiles data
-		ground_map = defaultdict(lambda: [])
+		ground_map = defaultdict(list)
 		for (coords, settlement_id) in settlement_map.iteritems():
 			ground_map[settlement_id].append(coords)
 
@@ -321,6 +326,31 @@ class SavegameUpgrader(object):
 		for row in db("SELECT rowid FROM building WHERE type = ?", BUILDINGS.FISH_DEPOSIT):
 			db("INSERT INTO fish_data(rowid, last_usage_tick) VALUES(?, ?)", row[0], -1000000)
 
+	def _upgrade_to_rev71(self, db):
+		old = 'MAX_INCR_REACHED'
+		new = 'MAX_TIER_REACHED'
+		db("UPDATE message_widget_active  SET id = ? WHERE id = ?", new, old)
+		db("UPDATE message_widget_archive SET id = ? WHERE id = ?", new, old)
+
+	def _upgrade_to_rev72(self, db):
+		# rename fire_disaster to building_influencing_disaster
+		db("ALTER TABLE fire_disaster RENAME TO building_influencing_disaster")
+
+	def _upgrade_to_rev73(self, db):
+		# Attempt to fix up corrupt yaml dumped into scenario savegames (#2164)
+		key = 'scenario_events'
+		try:
+			yaml_data = db("SELECT name, value FROM metadata WHERE name = ?", key)[0][1]
+		except IndexError:
+			# Not a scenario, nothing to repair
+			return
+		try:
+			YamlCache.load_yaml_data(yaml_data)
+		except ParserError:
+			messed_up = 'events: [ { actions: [ {'
+			yaml_data = yaml_data.replace(messed_up, '}, ' + messed_up)
+			db("UPDATE metadata SET value = ? WHERE name = ?", yaml_data, key)
+
 	def _upgrade(self):
 		# fix import loop
 		from horizons.savegamemanager import SavegameManager
@@ -331,6 +361,8 @@ class SavegameUpgrader(object):
 		elif rev == VERSION.SAVEGAMEREVISION: # the current version
 			self.final_path = self.original_path
 		else: # upgrade
+			self.log.warning('Discovered old savegame file, auto-upgrading: %s -> %s' % \
+						     (rev, VERSION.SAVEGAMEREVISION))
 			self.using_temp = True
 			handle, self.final_path = tempfile.mkstemp(prefix='uh-savegame.' + os.path.basename(os.path.splitext(self.original_path)[0]) + '.', suffix='.sqlite')
 			os.close(handle)
@@ -382,6 +414,12 @@ class SavegameUpgrader(object):
 				self._upgrade_to_rev69(db)
 			if rev < 70:
 				self._upgrade_to_rev70(db)
+			if rev < 71:
+				self._upgrade_to_rev71(db)
+			if rev < 72:
+				self._upgrade_to_rev72(db)
+			if 70 < rev < 73:
+				self._upgrade_to_rev73(db)
 
 			db('COMMIT')
 			db.close()
@@ -407,4 +445,4 @@ class SavegameUpgrader(object):
 			os.unlink(self.final_path)
 		self.final_path = None
 
-decorators.bind_all(SavegameUpgrader)
+decorators.bind_all(SavegameUpgrader)
\ No newline at end of file
