@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -91,20 +91,6 @@ class UhDbAccessor(DbReader):
 
 	# Building table
 
-	def get_building_tooltip(self, building_class_id):
-		"""Returns tooltip text of a building class.
-		ATTENTION: This text is automatically translated when loaded
-		already. DO NOT wrap the return value of this method in _()!
-		@param building_class_id: class of building, int
-		@return: string tooltip_text
-		"""
-		buildingtype = Entities.buildings[building_class_id]
-		#xgettext:python-format
-		# You usually do not need to change anything here when translating
-		tooltip = _("{building}: {description}")
-		return tooltip.format(building=_(buildingtype._name),
-		                      description=_(buildingtype.tooltip_text))
-
 	@decorators.cachedmethod
 	def get_related_building_ids(self, building_class_id):
 		"""Returns list of building ids related to building_class_id.
@@ -270,7 +256,6 @@ class UhDbAccessor(DbReader):
 		try:
 			comp = ship.get_component_template('StorageComponent')
 			storage = comp['PositiveTotalNumSlotsStorage']
-			#xgettext:python-format
 			# Ship storage properties
 			helptext = _('{slotnum} slots, {limit}t')
 			helptext = helptext.format(slotnum=storage['slotnum'],
@@ -280,7 +265,6 @@ class UhDbAccessor(DbReader):
 			pass
 		try:
 			comp = ship.get_component_template('HealthComponent')
-			#xgettext:python-format
 			helptext = _('Health: {health}')
 			helptext = helptext.format(health=comp['maxhealth'])
 			helptexts.append(helptext)
