@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -28,7 +28,6 @@ import horizons.globals
 from fife import fife
 
 from horizons.util.loaders.actionsetloader import ActionSetLoader
-from horizons.i18n.objecttranslations import object_translations
 from horizons.world.ingametype import IngameType
 from horizons.world.production.producer import Producer
 
@@ -50,12 +49,7 @@ class BuildingClass(IngameType):
 		super(BuildingClass, self).__init__(id, yaml_data)
 
 		self.settler_level = yaml_data['settler_level']
-		try:
-			# NOTE: tooltip texts are always untranslated here, use db.get_building_tooltip()
-			self.tooltip_text = object_translations[yaml_data['yaml_file']]['tooltip_text']
-		except KeyError: # not found => use value defined in yaml unless it is null
-			tooltip_text = yaml_data['tooltip_text']
-			self.tooltip_text = tooltip_text or u''
+		self.tooltip_text = self._strip_translation_marks(yaml_data['tooltip_text'])
 		self.size = (int(yaml_data['size_x']), int(yaml_data['size_y']))
 		self.width = self.size[0]
 		self.height = self.size[1]
@@ -77,7 +71,6 @@ class BuildingClass(IngameType):
 	def __str__(self):
 		return "Building[{id}]({name})".format(id=self.id, name=self.name)
 
-
 	def _loadObject(cls):
 		"""Loads building from the db.
 		"""
@@ -120,3 +113,14 @@ class BuildingClass(IngameType):
 			anim = horizons.globals.fife.animationloader.loadResource(path)
 			action.get2dGfxVisual().addAnimation(int(rotation), anim)
 			action.setDuration(anim.getDuration())
+
+	def get_tooltip(self):
+		"""Returns tooltip text of a building class.
+		ATTENTION: This text is automatically translated when loaded
+		already. DO NOT wrap the return value of this method in _()!
+		@return: string tooltip_text
+		"""
+		# You usually do not need to change anything here when translating
+		tooltip = _("{building}: {description}")
+		return tooltip.format(building=self._name,
+		                      description=self.tooltip_text)
