@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -23,6 +23,7 @@ from horizons.messaging import ResourceProduced
 from horizons.world.resourcehandler import ResourceHandler
 from horizons.world.production.producer import Producer
 
+
 class BuildingResourceHandler(ResourceHandler):
 	"""A Resourcehandler that is also a building.
 	This class exists because we keep a list of all buildings, that provide something at the island.
@@ -66,12 +67,9 @@ class BuildingResourceHandler(ResourceHandler):
 		return resources.keys()[0] in \
 		       self.island.session.db.get_res(only_tradeable=True, only_inventory=True)
 
-	def _set_running_costs_to_status(self, caller, is_active):
-		current_setting_is_active = self.running_costs_active()
-		if current_setting_is_active and not is_active:
-			self.toggle_costs()
-			self._changed()
-		elif not current_setting_is_active and is_active:
+	def _set_running_costs_to_status(self, caller, activate):
+		currently_active = self.running_costs_active()
+		if (currently_active and not activate) or (not currently_active and activate):
 			self.toggle_costs()
 			self._changed()
 
@@ -81,4 +79,3 @@ class UnitProducerBuilding(BuildingResourceHandler):
 	Uses a BuildingResourceHandler additionally to ResourceHandler to enable
 	building specific behavior."""
 	pass
-
