@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -199,6 +199,9 @@ class Settler(BuildableRect, BuildingResourceHandler, BasicBuilding):
 				# all lines, that were added here but are not used due to the current level
 				# NOTE: this contains the upgrade material production line
 				prod_comp.remove_production_by_id(line)
+				# Make sure to set _upgrade_production to None in case we are removing it
+				if self._upgrade_production is not None and line == self._upgrade_production.get_production_line_id():
+					self._upgrade_production = None
 
 		if not initial:
 			# update instance graphics
