@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -22,6 +22,7 @@
 import random
 
 from horizons.constants import ACTION_SETS
+from horizons.engine import Fife
 from horizons.scheduler import Scheduler
 from horizons.util.loaders.actionsetloader import ActionSetLoader
 from horizons.util.python.callback import Callback
@@ -57,7 +58,7 @@ class ConcreteObject(WorldObject):
 		self._action_set_id = action_set_id if action_set_id else self.__class__.get_random_action_set()
 
 		# only buildings for now
-		# NOTE: this is player dependant, therefore there must be no calls to session.random that depend on this
+		# NOTE: this is player dependent, therefore there must be no calls to session.random that depend on this
 		self.has_status_icon = self.is_building and self.show_status_icons and \
 			self.owner is not None and self.owner.is_local_player # and only for the player's buildings
 
@@ -103,7 +104,13 @@ class ConcreteObject(WorldObject):
 			if facing_loc is None:
 				facing_loc = self._instance.getFacingLocation()
 			UnitClass.ensure_action_loaded(self._action_set_id, action) # lazy
-			self._instance.act(action+"_"+str(self._action_set_id), facing_loc, repeating)
+			if (Fife.getVersion() >= (0, 3, 6)):
+				if repeating:
+					self._instance.actRepeat(action+"_"+str(self._action_set_id), facing_loc)
+				else:
+					self._instance.actOnce(action+"_"+str(self._action_set_id), facing_loc)
+			else:
+				self._instance.act(action+"_"+str(self._action_set_id), facing_loc, repeating)
 		self._action = action
 
 	def has_action(self, action):
