@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -139,6 +139,8 @@ class GroundClass(type):
 		"""Loads the ground object from the db (animations, etc)"""
 		cls._fife_objects = {}
 		tile_sets = TileSetLoader.get_sets()
+		model = horizons.globals.fife.engine.getModel()
+		load_image = horizons.globals.fife.animationloader.load_image
 		tile_set_data = db("SELECT set_id FROM tile_set WHERE ground_id=?", cls.id)
 		for tile_set_row in tile_set_data:
 			tile_set_id = str(tile_set_row[0])
@@ -146,17 +148,24 @@ class GroundClass(type):
 			cls.log.debug('Loading ground %s', cls_name)
 			fife_object = None
 			try:
-				fife_object = horizons.globals.fife.engine.getModel().createObject(cls_name, 'ground_' + tile_set_id)
+				fife_object = model.createObject(cls_name, 'ground_' + tile_set_id)
 			except RuntimeError:
 				cls.log.debug('Already loaded ground %d-%s', cls.id, cls.shape)
-				fife_object = horizons.globals.fife.engine.getModel().getObject(cls_name, 'ground_' + tile_set_id)
+				fife_object = model.getObject(cls_name, 'ground_' + tile_set_id)
 				return
 
 			fife.ObjectVisual.create(fife_object)
 			visual = fife_object.get2dGfxVisual()
 			for rotation, data in tile_sets[tile_set_id][cls.shape].iteritems():
-				assert len(data) == 1, 'Currently only static tiles are supported'
-				img = horizons.globals.fife.animationloader.load_image(data.keys()[0], tile_set_id, cls.shape, str(rotation))
+				if not data:
+					raise KeyError('No data found for tile set `%s` in rotation `%s`. '
+						'Most likely the shape `%s` is missing.' %
+						(tile_set_id, rotation, cls.shape))
+				if len(data) > 1:
+					raise ValueError('Currently only static tiles are supported. '
+						'Found this data for tile set `%s` in rotation `%s`: '
+						'%s' % (tile_set_id, rotation, data))
+				img = load_image(data.keys()[0], tile_set_id, cls.shape, str(rotation))
 				visual.addStaticImage(rotation, img.getHandle())
 
 			# Save the object
