@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2013 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 
@@ -114,23 +114,19 @@ class StatusIconManager(object):
 	def __render_status(self, instance, status):
 		status_string = self.get_status_string(instance)
 
-		# Clean icons
+		# Clear icons
 		self.renderer.removeAll(status_string)
 
 		# pixel-offset on screen (will be constant across zoom-levels)
 		rel = fife.Point(0, -30)
 
-
 		pos = instance.position
 
 		# trial and error has brought me to this (it's supposed to hit the center)
+		x = pos.origin.x + (pos.width / 4.0)
+		y = pos.origin.y + (pos.height / 4.0)
 		loc = fife.Location(self.layer)
-		loc.setExactLayerCoordinates(
-		  fife.ExactModelCoordinate(
-		    pos.origin.x + float(pos.width) / 4,
-		    pos.origin.y + float(pos.height) / 4,
-		  )
-		)
+		loc.setExactLayerCoordinates(fife.ExactModelCoordinate(x, y))
 
 		node = fife.RendererNode(loc, rel)
 
