@@ -1,5 +1,5 @@
 # ###################################################
-# Copyright (C) 2012 The Unknown Horizons Team
+# Copyright (C) 2008-2013 The Unknown Horizons Team
 # team@unknown-horizons.org
 # This file is part of Unknown Horizons.
 #
@@ -38,6 +38,7 @@ from horizons.messaging import AddStatusIcon, RemoveStatusIcon
 from horizons.world.production.utilization import Utilization, FullUtilization, FieldUtilization
 from horizons.util.python.callback import Callback
 from horizons.component.namedcomponent import NamedComponent
+from horizons.messaging import MineEmpty
 
 @metaChangeListenerDecorator("production_finished")
 @metaChangeListenerDecorator("activity_changed")
@@ -114,7 +115,7 @@ class Producer(Component):
 		if self.__auto_init:
 			for prod_line, attributes in self.production_lines.iteritems():
 				if 'enabled_by_default' in attributes and not attributes['enabled_by_default']:
-					continue  # It's set to false, don't add
+					continue  # It's set to False, don't add
 				prod = self.create_production(prod_line)
 				self.add_production(prod)
 		# For newly built producers we set the utilization to full for the first
@@ -456,7 +457,7 @@ class MineProducer(Producer):
 			# this is never going to change, the building is useless now.
 			if self.is_active():
 				self.set_active(active=False)
-			self.instance.owner.notify_mine_empty(self.instance)
+			MineEmpty.broadcast(self, self.instance)
 
 
 class QueueProducer(Producer):
@@ -505,8 +506,7 @@ class QueueProducer(Producer):
 		state = self._get_current_state()
 		return len(self.production_queue) > 0 and \
 		       (state is PRODUCTION.STATES.done or
-		        state is PRODUCTION.STATES.none or
-		        state is PRODUCTION.STATES.paused)
+		        state is PRODUCTION.STATES.none)
 
 	def on_queue_element_finished(self, production):
 		"""Callback used for the SingleUseProduction"""
@@ -531,7 +531,7 @@ class QueueProducer(Producer):
 
 	def cancel_current_production(self):
 		"""Cancels the current production and proceeds to the next one, if there is one"""
-		# Remove current productions, loose all progress and resources
+		# Remove current productions, lose all progress and resources
 		for production in self._productions.copy().itervalues():
 			self.remove_production(production)
 		for production in self._inactive_productions.copy().itervalues():
